@@ -8,20 +8,17 @@ OC.L10N.register(
     "Current" : "Actual",
     "Completed" : "Completado",
     "Tasks" : "Tareas",
-    "New List" : "Nueva Lista",
-    "Cancel" : "Cancelar",
-    "Save" : "Guardar",
-    "An empty name is not allowed." : "No se permite un nombre vacío.",
-    "Share with users or groups" : "Compartir con otros usuarios o grupos",
-    "can edit" : "puede editar",
-    "Edit" : "Editar",
-    "Download" : "Descargar",
-    "Delete" : "Borrar",
-    "Unshare" : "Dejar de compartir",
     "Visibility of Smart Collections" : "Visibilidad de Colecciones Inteligentes",
     "Hidden" : "Oculto",
     "Visible" : "Visible",
     "Automatic" : "Automático",
+    "Share with users or groups" : "Compartir con otros usuarios o grupos",
+    "Edit" : "Editar",
+    "Delete" : "Borrar",
+    "Unshare" : "Dejar de compartir",
+    "Cancel" : "Cancelar",
+    "Save" : "Guardar",
+    "An empty name is not allowed." : "No se permite un nombre vacío.",
     "Change sort order" : "Cambiar el criterio para ordenar",
     "Start date" : "Fecha de inicio",
     "Due date" : "Fecha de vencimiento",
@@ -32,12 +29,13 @@ OC.L10N.register(
     "Task is completed" : "La tarea ha sido completada",
     "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tarea Completada","%n Tareas Completadas"],
     "Tomorrow" : "Mañana",
-    "Set start date" : "Establecer fecha de inicio",
-    "Set due date" : "Establecer fecha de vencimiento",
+    "New List" : "Nueva Lista",
     "All day" : "Todo el día",
-    "Task not found!" : "¡Tarea no encontrada!",
     "When shared show full event" : "Al compartir, mostrar el evento completo",
     "When shared show only busy" : "Al compartir, mostrar sólo como ocupado ",
-    "When shared hide this event" : "Al compartir, ocultar este evento "
+    "When shared hide this event" : "Al compartir, ocultar este evento ",
+    "Task not found!" : "¡Tarea no encontrada!",
+    "Set start date" : "Establecer fecha de inicio",
+    "Set due date" : "Establecer fecha de vencimiento"
 },
 "nplurals=2; plural=(n != 1);");
