@@ -1,6 +1,7 @@
 OC.L10N.register(
     "tasks",
     {
+    "Upcoming tasks" : "今後のタスク",
     "Important" : "重要",
     "Today" : "今日",
     "Week" : "週",
@@ -9,7 +10,6 @@ OC.L10N.register(
     "Completed" : "完了",
     "Tasks" : "タスク",
     "The Tasks app for Nextcloud" : "Nextcloud用のタスクアプリ",
-    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "有効にすると、Nextcloudアプリのメニューに新しいタスクメニューが表示されます。 そこからタスクの追加や削除、タイトル、説明、開始日、期限を編集して重要なタスクとしてマークすることができます。 タスクはユーザー間で共有することができます。 タスクはCalDavを使って同期することができます。 各タスクリストはNextcloudのカレンダーにリンクされており、ローカルクライアント（Thunderbird、Evolution、KDE Kontact、iCalなど）と同期するには、クライアントのリモートカレンダーとしてカレンダーを追加します。 各カレンダーのダウンロードボタンを使って、タスクをICSファイルとしてダウンロードすることができます。",
     "Default list" : "デフォルトリスト",
     "Visibility of Smart Collections" : "スマートコレクションの表示",
     "Hidden" : "隠す",
@@ -23,7 +23,7 @@ OC.L10N.register(
     "Edit" : "編集",
     "Copy private link" : "プライベートリンクをコピー",
     "Copied" : "コピーしました",
-    "Download" : "ダウンロード",
+    "Cannot copy" : "コピーできません",
     "Delete" : "削除",
     "Unshare" : "共有を解除",
     "Cancel" : "キャンセル",
@@ -36,6 +36,11 @@ OC.L10N.register(
     "An empty name is not allowed." : "件名を入力してください。",
     "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
     "_Shared with {num} entity_::_Shared with {num} entities_" : ["{num}個のエンティティと共有"],
+    "Trash bin" : "ごみ箱",
+    "Name" : "名前",
+    "Unknown calendar" : "不明なカレンダー",
+    "Select a calendar" : "カレンダーを選択",
+    "Click here to add a note." : "クリックしてノートを追加",
     "Delete all completed tasks." : "全ての完了したタスクを削除",
     "Delete completed tasks." : "完了したタスクを削除",
     "Deleted all completed tasks from calendar \"{calendar}\"." : "カレンダー \"{calendar}\" から完了したタスクをすべて削除しました。",
@@ -66,8 +71,9 @@ OC.L10N.register(
     "Sort by summary and priority." : "要約と優先順位で並べ替えます。",
     "Manually" : "手動",
     "Sort by manual order." : "手動で並べ替えます。",
-    "Task is completed" : "タスク完了",
     "{complete} % completed" : "{complete} %完了",
+    "Task is pinned" : "タスクはピンされています",
+    "Task has a note" : "タスクにはノートがあります",
     "Add subtask" : "サブタスクを追加",
     "Show subtasks" : "サブタスクを表示",
     "Hide subtasks" : "サブタスクを非表示",
@@ -76,12 +82,24 @@ OC.L10N.register(
     "[Today]" : "[今日]",
     "[Tomorrow]" : "[明日]",
     "Add a subtask to \"{task}\"…" : "\"{task}\"にサブタスクを追加...",
+    "Task is completed" : "タスク完了",
+    "Create a new task" : "新しいタスクを作成する",
+    "Create task" : "タスクを作成する",
+    "Open task" : "タスクを開く",
+    "Close" : "閉じる",
     "_%n Completed Task_::_%n Completed Tasks_" : ["完了済みタスク %n"],
     "Tomorrow" : "明日",
     "Add List…" : "リストを追加…",
     "New List" : "新規リスト",
     "All day" : "終日",
+    "Unpin" : "ピンの解除",
+    "Pin" : "ピン",
+    "Show in Calendar" : "カレンダーに表示する",
+    "Edit title" : "タイトルを編集",
+    "Details" : "詳細",
     "Select a classification" : "分類を選択",
+    "Select a status" : "ステータスを選択",
+    "Select tags" : "タグを選択",
     "Notes" : "ノート",
     "When shared show full event" : "共有時にすべてのイベントを表示",
     "When shared show only busy" : "共有時に実行中のみを表示",
@@ -97,6 +115,7 @@ OC.L10N.register(
     "Set start date" : "開始日を設定",
     "[Due today]" : "[今日まで]",
     "[Due tomorrow]" : "[明日まで]",
+    "[Due on] LL" : "LL [まで]",
     "[Was due yesterday]" : "[昨日が期限]",
     "Set due date" : "期限を設定",
     "Priority {priority}: low" : "優先度{priority}:低",
@@ -104,6 +123,11 @@ OC.L10N.register(
     "Priority {priority}: high" : "優先度{priority}:高",
     "No priority assigned" : "優先順位が割り当てられていません",
     "{percent} % completed" : "{percent} %完了",
+    "upcoming tasks" : "今後のタスク",
+    "No tasks today" : "今日はタスクなし",
+    "Mark as done" : "完了としてマーク",
+    "No due date assigned" : "期限はありません",
+    "[Due] L" : "L [まで]",
     "Successfully created the task." : "タスクの作成に成功しました",
     "Could not delete the task." : "タスクを削除できませんでした",
     "Synchronizing to the server." : "サーバーと同期中",
@@ -111,6 +135,7 @@ OC.L10N.register(
     "Could not update the task because it was changed on the server. Please click to refresh it, local changes will be discarded." : "サーバー上でタスクが変更されたため、タスクを更新できませんでした。 クリックして更新してください。ローカルの変更は破棄されます。",
     "Could not update the task." : "タスクを更新できませんでした",
     "Successfully updated the task." : "タスクのアップデートに成功しました",
-    "An error occurred" : "エラーが発生しました"
+    "An error occurred" : "エラーが発生しました",
+    "Create a task" : "タスクを作成する"
 },
 "nplurals=1; plural=0;");
