@@ -10,7 +10,6 @@ OC.L10N.register(
     "Completed" : "完成",
     "Tasks" : "任务",
     "The Tasks app for Nextcloud" : "Nextcloud 任务应用",
-    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "启用后，新的“任务”菜单将出现在您的 Nextcloud 应用程序菜单中。 在这里，您可以添加和删除任务，编辑任务的标题，描述，开始日期和截止日期并将其标记为重要。 任务可以在用户之间共享。 可以使用 CalDav 同步任务（每个任务列表都链接到 Nextcloud 日历，以将其同步到本地客户端 - Thunderbird，Evolution，KDE Kontact，iCal … - 只需将日历添加为客户端中的远程日历即可）。 您可以使用每个日历的下载按钮将任务下载为 ICS 文件。",
     "Default list" : "默认列表",
     "Visibility of Smart Collections" : "智能集合的可见性",
     "Hidden" : "隐藏",
@@ -26,7 +25,6 @@ OC.L10N.register(
     "Copy private link" : "复制私人链接",
     "Copied" : "已复制",
     "Cannot copy" : "无法复制 ",
-    "Download" : "下载",
     "Delete" : "删除",
     "Unshare" : "取消共享",
     "Cancel" : "取消",
@@ -55,10 +53,19 @@ OC.L10N.register(
     "Deleted" : "已删除",
     "Restore" : "还原",
     "Delete permanently" : "永久删除",
+    "Empty trash bin" : "清空回收站",
+    "Untitled task" : "无标题任务",
+    "Untitled event" : "无标题事件",
+    "Untitled journal" : "无标题日记",
     "Untitled item" : "未命名项",
+    "Unknown calendar" : "未知日历",
     "Could not load deleted calendars and objects" : "无法加载已删除的日历和对象",
+    "Could not delete calendar or event" : "无法删除日历或事件",
     "Could not restore calendar or event" : "无法还原日历或事件",
+    "Do you really want to empty the trash bin?" : "你真想清空回收站吗？",
     "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["将于 {numDays} 后删除回收站内元素"],
+    "Select a calendar" : "选择一个日历",
+    "No calendar matches the search." : "没有同搜索相匹配的日历",
     "Set date" : "设置日期",
     "Set time" : "设置时间",
     "Delete date" : "删除日期",
@@ -98,7 +105,6 @@ OC.L10N.register(
     "Sort by summary and priority." : "按摘要和优先级排序。",
     "Manually" : "手动",
     "Sort by manual order." : "按手动顺序排序。",
-    "Task is completed" : "任务完成",
     "{complete} % completed" : "{complete} % 已完成",
     "Task has hidden subtasks" : "任务有隐藏的子任务",
     "Task is pinned" : "已固定任务",
@@ -126,6 +132,7 @@ OC.L10N.register(
     "[Completed] L [at] LT" : "[已完成] L [于] LT",
     "Add a subtask to \"{task}\"…" : "添加子任务到 \"{task}\" ...",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["在 {countdown} 秒后删除任务"],
+    "Task is completed" : "任务完成",
     "Create a new task" : "创建一个新任务",
     "Task summary" : "任务概要",
     "Create task" : "创建任务",
@@ -190,6 +197,7 @@ OC.L10N.register(
     "No upcoming tasks" : "没有即将到来的任务",
     "upcoming tasks" : "即将到来的任务",
     "No tasks today" : "今天没有任务",
+    "Mark as done" : "标记为已完成",
     "No due date assigned" : "未分配到期日",
     "Successfully created the task." : "成功创建任务。",
     "Could not delete the task." : "无法删除任务。",
@@ -200,6 +208,7 @@ OC.L10N.register(
     "Successfully updated the task." : "成功更新任务。",
     "Task successfully moved to new calendar." : "任务已成功移至新日历。",
     "An error occurred" : "发生了一个错误",
-    "Create a task" : "创建一个任务"
+    "Create a task" : "创建一个任务",
+    "Message from {author} in {conversationName}" : "{conversationName} 中来自 {author} 的消息"
 },
 "nplurals=1; plural=0;");
