@@ -10,7 +10,7 @@ OC.L10N.register(
     "Completed" : "完成",
     "Tasks" : "工作項目",
     "The Tasks app for Nextcloud" : "Nextcloud 的工作項目應用程式",
-    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client - Thunderbird, Evolution, KDE Kontact, iCal, … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「工作項目」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除工作項目、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。工作項目可在使用者間分享。工作項目可使用 CalDav 同步（每個工作項目列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的工作項目，只要按下每個日曆的下載按鈕就好。",
+    "Once enabled, a new Tasks menu will appear in your Nextcloud apps menu. From there you can add and delete tasks, edit their title, description, start and due dates and mark them as important. Tasks can be shared between users. Tasks can be synchronized using CalDav (each task list is linked to an Nextcloud calendar, to sync it to your local client: Thunderbird, Evolution, KDE Kontact, iCal … - just add the calendar as a remote calendar in your client). You can download your tasks as ICS files using the download button for each calendar." : "一經啟用，新的「工作項目」選單將會出現在您 Nextcloud 應用程式選單中。在此，您可以新增與刪除工作項目、編輯它們的標題、描述、開始與結束日期、標記它們的重要程度。工作項目可在使用者間分享。工作項目可使用 CalDav 同步（每個工作項目列表都會連結到一個 Nextcloud 日曆，用來與您的本機客戶端同步，如 Thunderbird、Evolution、KDE Kontact、iCal 等，只要在您的客戶端中以遠端日曆的形式新增日曆即可）。您可以 ICS 檔案的形式下載您的工作項目，只要按下每個日曆的下載按鈕就好。",
     "Default list" : "預設列表",
     "Visibility of Smart Collections" : "智慧型收藏的能見度",
     "Hidden" : "隱藏",
@@ -26,7 +26,7 @@ OC.L10N.register(
     "Copy private link" : "複製私人連結",
     "Copied" : "已複製",
     "Cannot copy" : "無法複製",
-    "Download" : "下載",
+    "Export" : "匯出",
     "Delete" : "刪除",
     "Unshare" : "撤回分享",
     "Cancel" : "取消",
@@ -55,10 +55,19 @@ OC.L10N.register(
     "Deleted" : "已刪除",
     "Restore" : "還原",
     "Delete permanently" : "永久刪除",
+    "Empty trash bin" : "清空回收桶",
+    "Untitled task" : "未命名工作項目",
+    "Untitled event" : "未命名活動",
+    "Untitled journal" : "未命名日誌",
     "Untitled item" : "未命名的項目",
+    "Unknown calendar" : "未知行事曆",
     "Could not load deleted calendars and objects" : "無法載入已刪除的日曆與物件",
+    "Could not delete calendar or event" : "無法刪除日曆或活動",
     "Could not restore calendar or event" : "無法還原日曆或活動",
+    "Do you really want to empty the trash bin?" : "您真的想要清空回收桶嗎？",
     "_Elements in the trash bin are deleted after {numDays} day_::_Elements in the trash bin are deleted after {numDays} days_" : ["回收桶中的元素將於{numDays}天後刪除"],
+    "Select a calendar" : "選取行事曆",
+    "No calendar matches the search." : "沒有與搜尋相符的日曆。",
     "Set date" : "設定日期",
     "Set time" : "設定時間",
     "Delete date" : "刪除日期",
@@ -98,7 +107,6 @@ OC.L10N.register(
     "Sort by summary and priority." : "按摘要與優先程度排序。",
     "Manually" : "手動",
     "Sort by manual order." : "手動排序。",
-    "Task is completed" : "工作項目已完成",
     "{complete} % completed" : "{complete} % 完成",
     "Task has hidden subtasks" : "工作項目有隱藏的子工作項目",
     "Task is pinned" : "工作項目已釘選",
@@ -126,6 +134,10 @@ OC.L10N.register(
     "[Completed] L [at] LT" : "[完成] L [於] LT",
     "Add a subtask to \"{task}\"…" : "新增子工作項目到「{task}」……",
     "_Deleting the task in {countdown} second_::_Deleting the task in {countdown} seconds_" : ["將在 {countdown} 秒後刪除工作項目"],
+    "Task is cancelled" : "工作項目已被取消",
+    "Task is completed" : "工作項目已完成",
+    "Task is read-only" : "工作項目唯讀",
+    "Task is not completed" : "工作項目未完成",
     "Create a new task" : "建立新工作項目",
     "Task summary" : "工作項目摘要",
     "Create task" : "建立工作項目",
@@ -203,6 +215,7 @@ OC.L10N.register(
     "No upcoming tasks" : "沒有接下來的工作",
     "upcoming tasks" : "接下來的工作",
     "No tasks today" : "今日無工作",
+    "Mark as done" : "標記為完成",
     "No due date assigned" : "未指定到期日",
     "[Due yesterday]" : "[昨天截止]",
     "[Due] L" : "[截止於] L",
